<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 10/19/2003 *
 * ===================                          Last change: 11/12/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-points.php                                  *
 * -------------------------------------------------------------------- *
 * Short description : All your collected points...                     *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Alle Ihrer gesammelten Punkte                    *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	exit();
} elseif (!isMember()) {
	redirectToIndexMemberOnlyModule();
}

// Add description as navigation point
addYouAreHereLink('member', __FILE__);

// Extension ext-user is highly required
if ((!isExtensionActive('user')) && (!isAdmin())) {
	displayMessage('{%pipe,generateExtensionInactiveNotInstalledMessage=user%}');
	return;
} // END - if

// Query for referral levels and percents
$result_depths = sqlQuery('SELECT `level`, `percents` FROM `{?_MYSQL_PREFIX?}_refdepths` ORDER BY `level` ASC', __FILE__, __LINE__);

// Get total depths
$numDepths = sqlNumRows($result_depths);

// Add many more rows for the login/turbo/ref/order bonus
// @TODO Should we rewrite this to a filter?
if (isExtensionActive('bonus')) {
	// Extension ext-bonus is there, okay
	if (isExtensionInstalledAndNewer('bonus', '0.2.2')) $numDepths += 6;
	if (isExtensionInstalledAndNewer('bonus', '0.4.4')) $numDepths += 4;
} else {
	// Not installed ext-bonus
	$numDepths += 1;
}

// Remember row count in constant
$content['rowspan'] = ($numDepths * 2 + 15);

// Initialize array elements
$content['part_points']         = '0.00000';
$content['part_referrals']      = '0';
$content['part_locked']         = '0.00000';
$content['part_order']          = '0.00000';
$content['part_locked_order']   = '0.00000';

// And output variable
$OUT = '';

// Load ref levels
while ($data = sqlFetchArray($result_depths)) {
	// Init points and counter here
	$content['counter']             = '0';
	$content['points']              = '0.00000';
	$content['order_points']        = '0.00000';
	$content['locked_points']       = '0.00000';
	$content['locked_order_points'] = '0.00000';

	// Merge it together
	$content = merge_array($content, $data);

	// Default for referral level > 0
	$depth = '`p`.`ref_depth`=%s';
	if (is_null($content['level'])) {
		$depth = '`p`.`ref_depth` IS NULL';
	} // END - if

	// Load referral points
	$result_points = sqlQueryEscaped('SELECT
	' . getAllPointColumns('p.', ',') . '
	`r`.`counter`
FROM
	`{?_MYSQL_PREFIX?}_user_points` AS `p`
LEFT JOIN
	`{?_MYSQL_PREFIX?}_refsystem` AS `r`
ON
	`p`.`userid`=`r`.`userid` AND
	`p`.`ref_depth`=`r`.`level`
WHERE
	`p`.`userid`=%s AND
	' . $depth . '
LIMIT 1',
		array(
			getMemberId(),
			convertZeroToNull($content['level'])
		), __FILE__, __LINE__);

	// Is there an entry?
	if (sqlNumRows($result_points) == 1) {
		// Load data
		$content = merge_array($content, sqlFetchArray($result_points));

		// Add locked-/points
		$content['part_points']       += $content['points'];
		$content['part_locked']       += $content['locked_points'];

		// For these columns, ext-order must be installed as well
		if (isExtensionInstalled('order')) {
			$content['part_order']        += $content['order_points'];
			$content['part_locked_order'] += $content['locked_order_points'];
		} // END - if

		// Add referral counter
		$content['part_referrals']    += $content['counter'];
	} // END - if

	// Free result
	sqlFreeResult($result_points);

	// Output row
	$OUT .= loadTemplate('member_points_row', TRUE, $content);
} // END - while

// Free memory
sqlFreeResult($result_depths);

// Add userid
$content['userid'] = getMemberId();

// Put rows to constant for the main template
$content['rows'] = $OUT;

// Fixes a bug when there is no bonus extension installed
if (isExtensionInstalledAndOlder('bonus', '0.4.4')) {
	setConfigEntry('bonus_active', 'X');
} // END - if

// Members shall see no special rows here
$content['special_rows'] = '';

// Display login bonus and turbo-click bonus
if ((isExtensionInstalledAndNewer('bonus', '0.2.2')) && (isExtensionActive('bonus')) && (isBonusRallyeActive())) {
	// Total bonus points
	$content['bonus_total_points'] = getUserData('turbo_bonus') + getUserData('login_bonus') + getUserData('bonus_ref') + getUserData('bonus_order') + getUserData('bonus_stats');

	// Output rows
	$content['special_rows'] = loadTemplate('member_points_bonus_rows', TRUE, $content);
} elseif ((isExtensionActive('bonus')) && (!isBonusRallyeActive())) {
	// Bonus active rallye deactivated
	$content['special_rows'] = loadTemplate('member_points_bonus_disabled', TRUE);
} elseif ((isAdmin()) && (isExtensionInstalledAndOlder('bonus', '0.2.2')) && (isExtensionActive('bonus'))) {
	// Please upgrade your bonus extension to v0.2.2 or newer!
	$content['special_rows'] = loadTemplate('member_points_upgrade');
}

// Load final template
if (isExtensionActive('user')) {
	// Load template when required extension is there
	loadTemplate('member_points', FALSE, $content);
} elseif (isAdmin()) {
	// Missing extension
	displayMessage('{%pipe,generateExtensionInactiveNotInstalledMessage=user%}');
} else {
	// Message for user
	displayMessage('{--PROBLEM_POINTS_OVERVIEW_UNAVAILABLE--}');
}

// Is ext-payout installed?
if (isExtensionActive('payout')) {
	// Payput extension is installed and active so we can check if the user has enougth points
	outputPayoutList($content['part_points'] - getUserData('used_points'));
} // END - if

// [EOF]
?>
