<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 02/28/2009 *
 * ===================                          Last change: 02/28/2009 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : request-functions.php                            *
 * -------------------------------------------------------------------- *
 * Short description : Special functions for request handling           *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Spezialle Funktionen fuer die Anfragebehandlung  *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Initialize the request elements
function initRequest () {
	$GLOBALS['raw_request']['get']  = (array) $_GET;
	$GLOBALS['raw_request']['post'] = (array) $_POST;
}

// Wrapper for elements in $_GET
function getRequestElement ($element) {
	// By default no element is there
	$value = NULL;

	// Is the element cached or there?
	if (isset($GLOBALS['cache_request']['get'][$element])) {
		// Then use the cache
		$value = $GLOBALS['cache_request']['get'][$element];
	} elseif (isGetRequestElementSet($element)) {
		// Then get it directly
		$value = sqlEscapeString($GLOBALS['raw_request']['get'][$element]);

		// Store it in cache
		$GLOBALS['cache_request']['get'][$element] = $value;
	} // END - if

	// Return value
	return $value;
}

// Checks if an element in $_GET exists
function isGetRequestElementSet ($element, $subElement = '') {
	if (empty($subElement)) {
		return ((isset($GLOBALS['raw_request']['get'][$element])) && ('' . ($GLOBALS['raw_request']['get'][$element] . '') != ''));
	} else {
		return ((isset($GLOBALS['raw_request']['get'][$element][$subElement])) && ('' . ($GLOBALS['raw_request']['get'][$element][$subElement] . '') != ''));
	}
}

// Removes an element from $_GET
function unsetGetRequestElement ($element) {
	unset($GLOBALS['cache_request']['get'][$element]);
	unset($GLOBALS['raw_request']['get'][$element]);
}

// Getter for whole $_GET array
function getRequestArray () {
	return $GLOBALS['raw_request']['get'];
}

// Counts entries in $_GET or returns false if not an array
function countRequestGet () {
	// By default this is not an array
	$count = FALSE;

	// Get the array
	$GET = getRequestArray();

	// Is it an array?
	if (is_array($GET)) {
		// Then count it
		$count = count($GET);
	} // END - if

	// Return value
}

// Setter for element in $_GET
function setGetRequestElement ($element, $value) {
	// Escape both
	$element = sqlEscapeString($element);
	$value   = sqlEscapeString($value);

	// Set in $_GET
	$GLOBALS['raw_request']['get'][$element] = $value;

	// Update cache
	$GLOBALS['cache_request']['get'][$element] = $value;
}

// Wrapper for elements in $_POST
function postRequestElement ($element, $subElement = NULL) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'element[' . gettype($element) . ']=' . $element . ',subElement[' . gettype($subElement) . ']=' . $subElement . ' - ENTERED!');
	// By default no element is there
	$value = NULL;

	// Is the element in cache?
	if (isset($GLOBALS['cache_request']['post'][$element][$subElement])) {
		// Then use it
		$value = $GLOBALS['cache_request']['post'][$element][$subElement];
		//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'element[' . gettype($element) . ']=' . $element . ',subElement[' . gettype($subElement) . ']=' . $subElement . ',value[' . gettype($value) . ']=' . $value . ' - CACHE!');
	} elseif (isPostRequestElementSet($element)) {
		// Then use it
		$value = $GLOBALS['raw_request']['post'][$element];

		// Is $subElement set?
		if ((!is_null($subElement)) && (isPostRequestElementSet($element, $subElement))) {
			// Then use this
			$value = sqlEscapeString($value[$subElement]);
			//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'element=' . $element . ',subElement=' . $subElement . ' - SUB!');
		} elseif ((!is_array($value)) && (function_exists('sqlEscapeString'))) {
			// Escape it here
			$value = sqlEscapeString($value);
			//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'element=' . $element . ' - REGULAR!');
		}

		// Set it in cache
		//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'element=' . $element . ',subElement=' . $subElement . ',value=' . $value.' - ADDED!');
		$GLOBALS['cache_request']['post'][$element][$subElement] = $value;
	} // END - if

	// Return value
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'element[' . gettype($element) . ']=' . $element . ',subElement[' . gettype($subElement) . ']=' . $subElement . ',value[' . gettype($value) . ']=' . $value . ' - EXIT!');
	return $value;
}

// Checks if an element in $_POST exists
function isPostRequestElementSet ($element, $subElement = NULL) {
	/*
	 * Always check that $element is a string and that $subElement is NULL or
	 * a string as numerical indexes are not wanted in POST data (in this
	 * project).
	 */
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'element[]=' . gettype($element) . ',subElement[]=' . gettype($subElement));
	assert(is_string($element) && ((is_null($subElement)) || (is_string($subElement)) || (is_int($subElement)) || (is_double($subElement))));

	// Is a sub element set?
	if (is_null($subElement)) {
		// No, then only check $element
		return ((isset($GLOBALS['raw_request']['post'][$element])) && ((is_array($GLOBALS['raw_request']['post'][$element])) || (('' . $GLOBALS['raw_request']['post'][$element] . '') != '')));
	} else {
		// Yes, then check both together
		return ((isset($GLOBALS['raw_request']['post'][$element][$subElement])) && (('' . $GLOBALS['raw_request']['post'][$element][$subElement] . '') != ''));
	}
}

// Removes an element from $_POST
function unsetPostRequestElement ($element) {
	unset($GLOBALS['raw_request']['post'][$element]);
	unset($GLOBALS['cache_request']['post'][$element]);
}

// Getter for whole $_POST array
function postRequestArray () {
	return $GLOBALS['raw_request']['post'];
}

// Setter for whole $_POST array
function setPostRequestArray ($postData) {
	$GLOBALS['raw_request']['post'] = $postData;
}

// Counts entries in $_POST or returns false if not an array
function countRequestPost () {
	// By default this is not an array
	$count = FALSE;

	// Get the array
	$postData = postRequestArray();

	// Is it an array?
	if (is_array($postData)) {
		// Then count it
		$count = count($postData);
	} // END - if

	// Return value
	return $count;
}

// Setter for element in $_POST
function setPostRequestElement ($element, $value) {
	// Is $element or $value an array?
	if (is_array($element)) {
		// Set array
		$eval = "\$GLOBALS['raw_request']['post']['";

		// Add all entries
		$eval .= implode("']['", $element);

		// Finish eval() command
		$eval .= sprintf("'] = \"%s\";", sqlEscapeString($value));

		// And run it
		eval($eval);
	} elseif (is_array($value)) {
		// Escape element
		$element = sqlEscapeString($element);

		// Value is an array so set it directly
		$GLOBALS['raw_request']['post'][$element] = $value;
	} else {
		// Debug message
		//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'element=' . $element . ',value=' . $value . ' - BEFORE!');

		// Escape both
		$element = sqlEscapeString($element);
		$value   = sqlEscapeString($value);

		// Debug message
		//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'element=' . $element . ',value=' . $value . ' - AFTER!');

		// Set regular entry
		$GLOBALS['raw_request']['post'][$element] = $value;
	}

	// Update cache
	$GLOBALS['cache_request']['post'][$element][NULL] = $value;
}

// Checks whether a form was sent. If so, the $_POST['ok'] element must be set
function isFormSent ($requestParameter = 'ok') {
	// Simply wrap it!
	return isPostRequestElementSet($requestParameter);
}

// Getter for request URI
function getRequestUri () {
	// Is it not set?
	if (!isset($_SERVER['REQUEST_URI'])) {
		// Return empty string
		return '';
	} // END - if

	// Return it
	return $_SERVER['REQUEST_URI'];
}

// Add all GET parameters to a string (without leading sign)
function addAllGetRequestParameters () {
	// Init variable
	$return = '';

	// Now add all parameters
	foreach (getRequestArray() as $key => $value) {
		// Add it secured
		$return .= sqlEscapeString($key) . '=' . sqlEscapeString($value) . '&amp;';
	} // END - foreach

	// Remove trailing &amp;
	$return = substr($return, 0, -5);

	// Return it
	return $return;
}

// [EOF]
?>
